/*****************************************************************************
 *
 * \file
 *
 * \brief CAN driver for AVR32 UC3.
 *
 * This file contains basic functions for the AVR32 CAN, with support for all
 * modes, settings and clock speeds.
 *
 * Copyright (c) 2009 Atmel Corporation. All rights reserved.
 *
 * \asf_license_start
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 * 3. The name of Atmel may not be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * 4. This software may only be redistributed and used in connection with an
 *    Atmel microcontroller product.
 *
 * THIS SOFTWARE IS PROVIDED BY ATMEL "AS IS" AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NON-INFRINGEMENT ARE
 * EXPRESSLY AND SPECIFICALLY DISCLAIMED. IN NO EVENT SHALL ATMEL BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * \asf_license_stop
 *
 ******************************************************************************/



#ifndef _CONF_CAN_EXAMPLE_H
#define _CONF_CAN_EXAMPLE_H

//_____ I N C L U D E S ________________________________________________________
#include "avr32/io.h"
#include "compiler.h"
#include "can.h"
#include "board.h"

/*
 *
 */
#if BOARD == UC3C_EK
#define UART_USART                     (&AVR32_USART2)
#define UART_USART_RX_PIN              AVR32_USART2_RXD_0_1_PIN
#define UART_USART_RX_FUNCTION         AVR32_USART2_RXD_0_1_FUNCTION
#define UART_USART_TX_PIN              AVR32_USART2_TXD_0_1_PIN
#define UART_USART_TX_FUNCTION         AVR32_USART2_TXD_0_1_FUNCTION
#define UART_USART_BAUDRATE            500000
#define UART_USART_IRQ                 AVR32_USART2_IRQ
#define UART_USART_IRQ_LEVEL           AVR32_INTC_INT1
#define FPBA_HZ                        FOSC0
#elif BOARD == UC3_C2_XPLAINED
#define UART_USART                     (&AVR32_USART3)
#define UART_USART_RX_PIN              AVR32_USART3_RXD_2_PIN
#define UART_USART_RX_FUNCTION         AVR32_USART3_RXD_2_FUNCTION
#define UART_USART_TX_PIN              AVR32_USART3_TXD_2_PIN
#define UART_USART_TX_FUNCTION         AVR32_USART3_TXD_2_FUNCTION
#define UART_USART_BAUDRATE            500000
#define UART_USART_IRQ                 AVR32_USART3_IRQ
#define UART_USART_IRQ_LEVEL           AVR32_INTC_INT1
#define FPBA_HZ                        FOSC0
#else
#error 'Board not supported by the example!'
#endif


//! \note TC0 module is used in this example.
#define EXAMPLE_TC                 (&AVR32_TC0)
//! \note TC Channel 0 is used.
#define EXAMPLE_TC_CHANNEL         0
//! \note IRQ0 line of TC0 module channel 0 is used.
#define EXAMPLE_TC_IRQ             AVR32_TC0_IRQ0
//! \note IRQ Group of TC0 module
#define EXAMPLE_TC_IRQ_GROUP       AVR32_TC0_IRQ_GROUP
//! \note Interrupt priority 0 is used for TC in this example.
#define EXAMPLE_TC_IRQ_PRIORITY    AVR32_INTC_INT0

/*
 *	Mail Box Definition
 */
// -----------------------------------------------------------------
// CAN Message Definition: Tx Message
#if defined (__ICCAVR32__)
can_msg_t msg_1 =
{
    0x3C1,       // Identifier
    0x3C1,      // Mask
    0x0LL,     // Data
};
#else
can_msg_t msg_1 =
{
  {
    {
      .id = 0x3C1,       // Identifier
      .id_mask  = 0x3C1, // Mask
    },
  },
 .data.u64 = 0x0LL,    // Data
};
#endif

// MOB Message Definition: Transmit Message
can_mob_t transmit_msg1[1] = 
{ {CAN_MOB_NOT_ALLOCATED, &msg_1,8,CAN_DATA_FRAME, CAN_STATUS_NOT_COMPLETED}	};			  


// CAN Message Definition: Tx Message
#if defined (__ICCAVR32__)
can_msg_t msg_2 =
{
	0x3C2,       // Identifier
	0x3C2,      // Mask
	0x0LL,     // Data
};
#else
can_msg_t msg_2 =
{
	{
		{
			.id = 0x3C2,       // Identifier
			.id_mask  = 0x3C2, // Mask
		},
	},
	.data.u64 = 0x0LL,    // Data
};
#endif

// MOB Message Definition: Transmit Message
can_mob_t transmit_msg2[1] =
{ {CAN_MOB_NOT_ALLOCATED, &msg_2,8,CAN_DATA_FRAME, CAN_STATUS_NOT_COMPLETED}	};	


// -----------------------------------------------------------------
// CAN Message Definition: Receive Message
#if defined (__ICCAVR32__)
can_msg_t rcv_1 =
{
     3C1,		// Identifier
     3C1,       // Mask
     0x0LL,    // Data
};
#else
can_msg_t rcv_1 =
{
  {
    {
      .id = 0x3C1,         // Identifier
      .id_mask  = 0x3C1,  // Mask
    },
  },
 .data.u64 = 0x0LL,     // Data
};
#endif

// MOB Message Definition: Receive Message
can_mob_t receive_msg1[1] = 
{ {CAN_MOB_NOT_ALLOCATED,&rcv_1,8,CAN_DATA_FRAME,CAN_STATUS_NOT_COMPLETED } };

// CAN Message Definition: Receive Message
#if defined (__ICCAVR32__)
can_msg_t rcv_2 =
{
	3C2,		// Identifier
	3C2,       // Mask
	0x0LL,    // Data
};
#else
can_msg_t rcv_2 =
{
	{
		{
			.id = 0x3C2,         // Identifier
			.id_mask  = 0x3C2,  // Mask
		},
	},
	.data.u64 = 0x0LL,     // Data
};
#endif

// MOB Message Definition: Receive Message
can_mob_t receive_msg2[1] =
{ {CAN_MOB_NOT_ALLOCATED,&rcv_2,8,CAN_DATA_FRAME,CAN_STATUS_NOT_COMPLETED } };


#endif // _CONF_CAN_EXAMPLE_H
